Class: Google::Apis::SafebrowsingV5::GoogleSecuritySafebrowsingV5BatchGetHashListsResponse
- Inherits:
-
Object
- Object
- Google::Apis::SafebrowsingV5::GoogleSecuritySafebrowsingV5BatchGetHashListsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/safebrowsing_v5/classes.rb,
lib/google/apis/safebrowsing_v5/representations.rb,
lib/google/apis/safebrowsing_v5/representations.rb
Overview
The response containing multiple hash lists.
Instance Attribute Summary collapse
-
#hash_lists ⇒ Array<Google::Apis::SafebrowsingV5::GoogleSecuritySafebrowsingV5HashList>
The hash lists in the same order given in the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleSecuritySafebrowsingV5BatchGetHashListsResponse
constructor
A new instance of GoogleSecuritySafebrowsingV5BatchGetHashListsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleSecuritySafebrowsingV5BatchGetHashListsResponse
Returns a new instance of GoogleSecuritySafebrowsingV5BatchGetHashListsResponse.
34 35 36 |
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 34 def initialize(**args) update!(**args) end |
Instance Attribute Details
#hash_lists ⇒ Array<Google::Apis::SafebrowsingV5::GoogleSecuritySafebrowsingV5HashList>
The hash lists in the same order given in the request.
Corresponds to the JSON property hashLists
32 33 34 |
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 32 def hash_lists @hash_lists end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39 40 41 |
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 39 def update!(**args) @hash_lists = args[:hash_lists] if args.key?(:hash_lists) end |