Class: Google::Apis::SafebrowsingV5::GoogleSecuritySafebrowsingV5FullHashFullHashDetail
- Inherits:
-
Object
- Object
- Google::Apis::SafebrowsingV5::GoogleSecuritySafebrowsingV5FullHashFullHashDetail
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/safebrowsing_v5/classes.rb,
lib/google/apis/safebrowsing_v5/representations.rb,
lib/google/apis/safebrowsing_v5/representations.rb
Overview
Details about a matching full hash. An important note about forward
compatibility: new threat types and threat attributes may be added by the
server at any time; those additions are considered minor version changes. It
is Google's policy not to expose minor version numbers in APIs (see https://
cloud.google.com/apis/design/versioning for the versioning policy), so clients
MUST be prepared to receive FullHashDetail messages containing ThreatType
enum values or ThreatAttribute enum values that are considered invalid by
the client. Therefore, it is the client's responsibility to check for the
validity of all ThreatType and ThreatAttribute enum values; if any value
is considered invalid, the client MUST disregard the entire FullHashDetail
message.
Instance Attribute Summary collapse
-
#attributes ⇒ Array<String>
Unordered list.
-
#threat_type ⇒ String
The type of threat.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleSecuritySafebrowsingV5FullHashFullHashDetail
constructor
A new instance of GoogleSecuritySafebrowsingV5FullHashFullHashDetail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleSecuritySafebrowsingV5FullHashFullHashDetail
Returns a new instance of GoogleSecuritySafebrowsingV5FullHashFullHashDetail.
97 98 99 |
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 97 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attributes ⇒ Array<String>
Unordered list. Additional attributes about those full hashes. This may be
empty.
Corresponds to the JSON property attributes
90 91 92 |
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 90 def attributes @attributes end |
#threat_type ⇒ String
The type of threat. This field will never be empty.
Corresponds to the JSON property threatType
95 96 97 |
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 95 def threat_type @threat_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
102 103 104 105 |
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 102 def update!(**args) @attributes = args[:attributes] if args.key?(:attributes) @threat_type = args[:threat_type] if args.key?(:threat_type) end |