Class: Google::Apis::SafebrowsingV5::GoogleSecuritySafebrowsingV5ListHashListsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/safebrowsing_v5/classes.rb,
lib/google/apis/safebrowsing_v5/representations.rb,
lib/google/apis/safebrowsing_v5/representations.rb

Overview

The response containing metadata about hash lists.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleSecuritySafebrowsingV5ListHashListsResponse

Returns a new instance of GoogleSecuritySafebrowsingV5ListHashListsResponse.



290
291
292
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 290

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hash_listsArray<Google::Apis::SafebrowsingV5::GoogleSecuritySafebrowsingV5HashList>

The hash lists in an arbitrary order. Only metadata about the hash lists will be included, not the contents. Corresponds to the JSON property hashLists



282
283
284
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 282

def hash_lists
  @hash_lists
end

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


288
289
290
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 288

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



295
296
297
298
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 295

def update!(**args)
  @hash_lists = args[:hash_lists] if args.key?(:hash_lists)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end