Class: Google::Apis::SafebrowsingV5::GoogleSecuritySafebrowsingV5RiceDeltaEncoded256Bit

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/safebrowsing_v5/classes.rb,
lib/google/apis/safebrowsing_v5/representations.rb,
lib/google/apis/safebrowsing_v5/representations.rb

Overview

Same as RiceDeltaEncoded32Bit except this encodes 256-bit numbers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleSecuritySafebrowsingV5RiceDeltaEncoded256Bit

Returns a new instance of GoogleSecuritySafebrowsingV5RiceDeltaEncoded256Bit.



397
398
399
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 397

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#encoded_dataString

The encoded deltas that are encoded using the Golomb-Rice coder. Corresponds to the JSON property encodedData NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


358
359
360
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 358

def encoded_data
  @encoded_data
end

#entries_countFixnum

The number of entries that are delta encoded in the encoded data. If only a single integer was encoded, this will be zero and the single value will be stored in first_value. Corresponds to the JSON property entriesCount

Returns:

  • (Fixnum)


365
366
367
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 365

def entries_count
  @entries_count
end

#first_value_first_partFixnum

The first 64 bits of the first entry in the encoded data (hashes). If the field is empty, the first 64 bits are all zero. Corresponds to the JSON property firstValueFirstPart

Returns:

  • (Fixnum)


371
372
373
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 371

def first_value_first_part
  @first_value_first_part
end

#first_value_fourth_partFixnum

The last 64 bits of the first entry in the encoded data (hashes). If the field is empty, the last 64 bits are all zero. Corresponds to the JSON property firstValueFourthPart

Returns:

  • (Fixnum)


377
378
379
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 377

def first_value_fourth_part
  @first_value_fourth_part
end

#first_value_second_partFixnum

The 65 through 128th bits of the first entry in the encoded data (hashes). If the field is empty, the 65 through 128th bits are all zero. Corresponds to the JSON property firstValueSecondPart

Returns:

  • (Fixnum)


383
384
385
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 383

def first_value_second_part
  @first_value_second_part
end

#first_value_third_partFixnum

The 129 through 192th bits of the first entry in the encoded data (hashes). If the field is empty, the 129 through 192th bits are all zero. Corresponds to the JSON property firstValueThirdPart

Returns:

  • (Fixnum)


389
390
391
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 389

def first_value_third_part
  @first_value_third_part
end

#rice_parameterFixnum

The Golomb-Rice parameter. This parameter is guaranteed to be between 227 and 254, inclusive. Corresponds to the JSON property riceParameter

Returns:

  • (Fixnum)


395
396
397
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 395

def rice_parameter
  @rice_parameter
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



402
403
404
405
406
407
408
409
410
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 402

def update!(**args)
  @encoded_data = args[:encoded_data] if args.key?(:encoded_data)
  @entries_count = args[:entries_count] if args.key?(:entries_count)
  @first_value_first_part = args[:first_value_first_part] if args.key?(:first_value_first_part)
  @first_value_fourth_part = args[:first_value_fourth_part] if args.key?(:first_value_fourth_part)
  @first_value_second_part = args[:first_value_second_part] if args.key?(:first_value_second_part)
  @first_value_third_part = args[:first_value_third_part] if args.key?(:first_value_third_part)
  @rice_parameter = args[:rice_parameter] if args.key?(:rice_parameter)
end