Module: Google::Apis::SafebrowsingV5
- Defined in:
- lib/google/apis/safebrowsing_v5.rb,
lib/google/apis/safebrowsing_v5/classes.rb,
lib/google/apis/safebrowsing_v5/service.rb,
lib/google/apis/safebrowsing_v5/gem_version.rb,
lib/google/apis/safebrowsing_v5/representations.rb
Overview
Safe Browsing API
Enables client applications to check web resources (most commonly URLs) against Google-generated lists of unsafe web resources. The Safe Browsing APIs are for non-commercial use only. If you need to use APIs to detect malicious URLs for commercial purposes – meaning “for sale or revenue-generating purposes” – please refer to the Web Risk API.
Defined Under Namespace
Classes: GoogleSecuritySafebrowsingV5BatchGetHashListsResponse, GoogleSecuritySafebrowsingV5FullHash, GoogleSecuritySafebrowsingV5FullHashFullHashDetail, GoogleSecuritySafebrowsingV5HashList, GoogleSecuritySafebrowsingV5HashListMetadata, GoogleSecuritySafebrowsingV5ListHashListsResponse, GoogleSecuritySafebrowsingV5RiceDeltaEncoded128Bit, GoogleSecuritySafebrowsingV5RiceDeltaEncoded256Bit, GoogleSecuritySafebrowsingV5RiceDeltaEncoded32Bit, GoogleSecuritySafebrowsingV5RiceDeltaEncoded64Bit, GoogleSecuritySafebrowsingV5SearchHashesResponse, GoogleSecuritySafebrowsingV5SearchUrlsResponse, GoogleSecuritySafebrowsingV5ThreatUrl, SafebrowsingService
Constant Summary collapse
- GEM_VERSION =
Version of the google-apis-safebrowsing_v5 gem
"0.10.0"- GENERATOR_VERSION =
Version of the code generator used to generate this client
"0.19.0"- REVISION =
Revision of the discovery document this client was generated from
"20251214"- VERSION =
Version of the Safe Browsing API this client connects to. This is NOT the gem version.
'V5'