Class: Google::Apis::SafebrowsingV5::GoogleSecuritySafebrowsingV5HashListMetadata
- Inherits:
-
Object
- Object
- Google::Apis::SafebrowsingV5::GoogleSecuritySafebrowsingV5HashListMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/safebrowsing_v5/classes.rb,
lib/google/apis/safebrowsing_v5/representations.rb,
lib/google/apis/safebrowsing_v5/representations.rb
Overview
Metadata about a particular hash list.
Instance Attribute Summary collapse
-
#description ⇒ String
A human-readable description about this list.
-
#hash_length ⇒ String
The supported hash length for this hash list.
-
#likely_safe_types ⇒ Array<String>
Unordered list.
-
#threat_types ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleSecuritySafebrowsingV5HashListMetadata
constructor
A new instance of GoogleSecuritySafebrowsingV5HashListMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleSecuritySafebrowsingV5HashListMetadata
Returns a new instance of GoogleSecuritySafebrowsingV5HashListMetadata.
261 262 263 |
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 261 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
A human-readable description about this list. Written in English.
Corresponds to the JSON property description
236 237 238 |
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 236 def description @description end |
#hash_length ⇒ String
The supported hash length for this hash list. Each hash list will support
exactly one length. If a different hash length is introduced for the same set
of threat types or safe types, it will be introduced as a separate list with a
distinct name and respective hash length set.
Corresponds to the JSON property hashLength
244 245 246 |
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 244 def hash_length @hash_length end |
#likely_safe_types ⇒ Array<String>
Unordered list. If not empty, this specifies that the hash list represents a
list of likely safe hashes, and this enumerates the ways they are considered
likely safe. This field is mutually exclusive with the threat_types field.
Corresponds to the JSON property likelySafeTypes
251 252 253 |
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 251 def likely_safe_types @likely_safe_types end |
#threat_types ⇒ Array<String>
Unordered list. If not empty, this specifies that the hash list is a kind of
threat list, and this enumerates the kind of threats associated with hashes or
hash prefixes in this hash list. May be empty if the entry does not represent
a threat, i.e. in the case that it represents a likely safe type.
Corresponds to the JSON property threatTypes
259 260 261 |
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 259 def threat_types @threat_types end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
266 267 268 269 270 271 |
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 266 def update!(**args) @description = args[:description] if args.key?(:description) @hash_length = args[:hash_length] if args.key?(:hash_length) @likely_safe_types = args[:likely_safe_types] if args.key?(:likely_safe_types) @threat_types = args[:threat_types] if args.key?(:threat_types) end |