Class: Google::Apis::SafebrowsingV5::GoogleSecuritySafebrowsingV5RiceDeltaEncoded128Bit
- Inherits:
-
Object
- Object
- Google::Apis::SafebrowsingV5::GoogleSecuritySafebrowsingV5RiceDeltaEncoded128Bit
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/safebrowsing_v5/classes.rb,
lib/google/apis/safebrowsing_v5/representations.rb,
lib/google/apis/safebrowsing_v5/representations.rb
Overview
Same as RiceDeltaEncoded32Bit except this encodes 128-bit numbers.
Instance Attribute Summary collapse
-
#encoded_data ⇒ String
The encoded deltas that are encoded using the Golomb-Rice coder.
-
#entries_count ⇒ Fixnum
The number of entries that are delta encoded in the encoded data.
-
#first_value_hi ⇒ Fixnum
The upper 64 bits of the first entry in the encoded data (hashes).
-
#first_value_lo ⇒ Fixnum
The lower 64 bits of the first entry in the encoded data (hashes).
-
#rice_parameter ⇒ Fixnum
The Golomb-Rice parameter.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleSecuritySafebrowsingV5RiceDeltaEncoded128Bit
constructor
A new instance of GoogleSecuritySafebrowsingV5RiceDeltaEncoded128Bit.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleSecuritySafebrowsingV5RiceDeltaEncoded128Bit
Returns a new instance of GoogleSecuritySafebrowsingV5RiceDeltaEncoded128Bit.
336 337 338 |
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 336 def initialize(**args) update!(**args) end |
Instance Attribute Details
#encoded_data ⇒ String
The encoded deltas that are encoded using the Golomb-Rice coder.
Corresponds to the JSON property encodedData
NOTE: Values are automatically base64 encoded/decoded in the client library.
309 310 311 |
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 309 def encoded_data @encoded_data end |
#entries_count ⇒ Fixnum
The number of entries that are delta encoded in the encoded data. If only a
single integer was encoded, this will be zero and the single value will be
stored in first_value.
Corresponds to the JSON property entriesCount
316 317 318 |
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 316 def entries_count @entries_count end |
#first_value_hi ⇒ Fixnum
The upper 64 bits of the first entry in the encoded data (hashes). If the
field is empty, the upper 64 bits are all zero.
Corresponds to the JSON property firstValueHi
322 323 324 |
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 322 def first_value_hi @first_value_hi end |
#first_value_lo ⇒ Fixnum
The lower 64 bits of the first entry in the encoded data (hashes). If the
field is empty, the lower 64 bits are all zero.
Corresponds to the JSON property firstValueLo
328 329 330 |
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 328 def first_value_lo @first_value_lo end |
#rice_parameter ⇒ Fixnum
The Golomb-Rice parameter. This parameter is guaranteed to be between 99 and
126, inclusive.
Corresponds to the JSON property riceParameter
334 335 336 |
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 334 def rice_parameter @rice_parameter end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
341 342 343 344 345 346 347 |
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 341 def update!(**args) @encoded_data = args[:encoded_data] if args.key?(:encoded_data) @entries_count = args[:entries_count] if args.key?(:entries_count) @first_value_hi = args[:first_value_hi] if args.key?(:first_value_hi) @first_value_lo = args[:first_value_lo] if args.key?(:first_value_lo) @rice_parameter = args[:rice_parameter] if args.key?(:rice_parameter) end |