Class: Google::Apis::SafebrowsingV5::GoogleSecuritySafebrowsingV5RiceDeltaEncoded64Bit
- Inherits:
-
Object
- Object
- Google::Apis::SafebrowsingV5::GoogleSecuritySafebrowsingV5RiceDeltaEncoded64Bit
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/safebrowsing_v5/classes.rb,
lib/google/apis/safebrowsing_v5/representations.rb,
lib/google/apis/safebrowsing_v5/representations.rb
Overview
Same as RiceDeltaEncoded32Bit except this encodes 64-bit numbers.
Instance Attribute Summary collapse
-
#encoded_data ⇒ String
The encoded deltas that are encoded using the Golomb-Rice coder.
-
#entries_count ⇒ Fixnum
The number of entries that are delta encoded in the encoded data.
-
#first_value ⇒ Fixnum
The first entry in the encoded data (hashes), or, if only a single hash prefix was encoded, that entry's value.
-
#rice_parameter ⇒ Fixnum
The Golomb-Rice parameter.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleSecuritySafebrowsingV5RiceDeltaEncoded64Bit
constructor
A new instance of GoogleSecuritySafebrowsingV5RiceDeltaEncoded64Bit.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleSecuritySafebrowsingV5RiceDeltaEncoded64Bit
Returns a new instance of GoogleSecuritySafebrowsingV5RiceDeltaEncoded64Bit.
498 499 500 |
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 498 def initialize(**args) update!(**args) end |
Instance Attribute Details
#encoded_data ⇒ String
The encoded deltas that are encoded using the Golomb-Rice coder.
Corresponds to the JSON property encodedData
NOTE: Values are automatically base64 encoded/decoded in the client library.
477 478 479 |
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 477 def encoded_data @encoded_data end |
#entries_count ⇒ Fixnum
The number of entries that are delta encoded in the encoded data. If only a
single integer was encoded, this will be zero and the single value will be
stored in first_value.
Corresponds to the JSON property entriesCount
484 485 486 |
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 484 def entries_count @entries_count end |
#first_value ⇒ Fixnum
The first entry in the encoded data (hashes), or, if only a single hash prefix
was encoded, that entry's value. If the field is empty, the entry is zero.
Corresponds to the JSON property firstValue
490 491 492 |
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 490 def first_value @first_value end |
#rice_parameter ⇒ Fixnum
The Golomb-Rice parameter. This parameter is guaranteed to be between 35 and
62, inclusive.
Corresponds to the JSON property riceParameter
496 497 498 |
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 496 def rice_parameter @rice_parameter end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
503 504 505 506 507 508 |
# File 'lib/google/apis/safebrowsing_v5/classes.rb', line 503 def update!(**args) @encoded_data = args[:encoded_data] if args.key?(:encoded_data) @entries_count = args[:entries_count] if args.key?(:entries_count) @first_value = args[:first_value] if args.key?(:first_value) @rice_parameter = args[:rice_parameter] if args.key?(:rice_parameter) end |